## What's Changed

- chore: bump version to 0.1.4, add pydantic dependency, and define DateInfo model for date information (c6055b6)

**Full Changelog**: https://github.com/leynier/mcp-sys-bridge/compare/v0.1.3...v0.1.4

